===============
django-inviter2
===============

.. image:: https://travis-ci.org/mjschultz/django-inviter2.svg?branch=master
    :target: https://travis-ci.org/mjschultz/django-inviter2
    :alt: Build status

.. image:: https://coveralls.io/repos/mjschultz/django-inviter2/badge.png?branch=master
    :target: https://coveralls.io/r/mjschultz/django-inviter2?branch=master
    :alt: Coverage status

Let your users invite new users.

Useful if you want your webapp to be in a private beta mode or for only permitting access to known users.

Installation
============

    $ pip install django-inviter2

Version Support
===============

We try to maintain support at or near Django's `supported versions`_.

- Django 3.2 (requires Python 3.6, 3.7, 3.8, 3.9, or 3.10)
- Django 4.0 (requires Python 3.8, 3.9, or 3.10)

.. _supported versions: https://www.djangoproject.com/download/

History
=======

This is a fork of django-inviter_.

.. _django-inviter: https://github.com/caffeinehit/django-inviter


Documentation is available via `Read the Docs`_

.. _Read the Docs: https://django-inviter2.readthedocs.org/
